%define anolis_release 2
# When we are bootstrapping, we drop some dependencies.
%bcond_with bootstrap

Name:           libproxy
Version:        0.4.18
Release:        %{anolis_release}%{?dist}
Summary:        A library handling all the details of proxy configuration

License:        LGPLv2+
URL:            https://libproxy.github.io/libproxy/
Source0:        https://github.com/libproxy/%{name}/releases/download/%{name}-%{version}.tar.xz
# Taken from the Debian package.
Source1:        proxy.1

BuildRequires:  cmake >= 2.6.0
BuildRequires:  gcc-c++

%if %{without bootstrap}
# gnome
BuildRequires:  pkgconfig(gio-2.0) >= 2.26
# NetworkManager
BuildRequires:  pkgconfig(libnm)
# ConnMan's pacrunner (and NetworkManager)
BuildRequires:  pkgconfig(dbus-1)
# for libproxy's duktape pacrunner
BuildRequires:  pkgconfig(duktape)
# Python
BuildRequires:  python3-devel
%endif


%description
libproxy offers the following features:

    * extremely small core footprint (< 35K)
    * no external dependencies within libproxy core
      (libproxy plugins may have dependencies)
    * only 4 functions in the stable external API
    * dynamic adjustment to changing network topology
    * a standard way of dealing with proxy settings across all scenarios
    * a sublime sense of joy and accomplishment


%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%package        bin
Summary:        Binary to test %{name}
Requires:       %{name} = %{version}-%{release}

%description    bin
The %{name}-bin package contains the proxy binary for %{name}

%if %{without bootstrap}
%package -n     python3-%{name}
Summary:        Binding for %{name} and python3
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch
%{?python_provide:%python_provide python3-%{name}}

%description -n python3-%{name}
The python3 binding for %{name}

%package        gnome
Summary:        Plugin for %{name} and gnome
Requires:       %{name} = %{version}-%{release}

%description    gnome
The %{name}-gnome package contains the %{name} plugin for gnome.

%package        networkmanager
Summary:        Plugin for %{name} and networkmanager
Requires:       %{name} = %{version}-%{release}

%description    networkmanager
The %{name}-networkmanager package contains the %{name} plugin
for networkmanager.

%package        duktape            
Summary:        Plugin for %{name} and duktape            
Requires:       %{name} = %{version}-%{release}            
Provides:       %{name}-pac = %{version}-%{release}            
Obsoletes:      %{name}-mozjs <= %{EVR}            
Obsoletes:      %{name}-webkitgtk4 <= %{EVR}            

%description    duktape            
The %{name}-duktape package contains the %{name} plugin for            
duktape.

%package        pacrunner
Summary:        Plugin for %{name} and PacRunner
Requires:       %{name} = %{version}-%{release}
Provides:       %{name}-pac = %{version}-%{release}
Requires:       pacrunner

%description    pacrunner
The %{name}-pacrunner package contains the %{name} plugin for
ConnMan's PacRunner.
%endif

%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%prep
%autosetup -p1

%build
export CXXFLAGS="-std=c++14 $RPM_OPT_FLAGS"
%cmake \
  -DMODULE_INSTALL_DIR=%{_libdir}/%{name}/%{version}/modules \
  -DBIPR=OFF \
  -DWITH_GNOME=OFF \
  -DWITH_MOZJS=OFF \
  -DWITH_PERL=OFF \
  -DWITH_PYTHON2=OFF \
  -DWITH_WEBKIT=OFF \
  -DWITH_WEBKIT3=OFF \
  -DWITH_KDE=OFF \
%if %{without bootstrap}
  -DWITH_DUKTAPE=ON \
  -DWITH_GNOME3=ON \
  -DWITH_PYTHON3=ON \
%else
  -DWITH_DUKTAPE=OFF \
  -DWITH_GNOME3=OFF \
  -DWITH_PYTHON3=OFF \
%endif
  %{nil}
%cmake_build

%install
%cmake_install

#In case all modules are disabled
mkdir -p %{buildroot}%{_libdir}/%{name}/%{version}/modules

# Man page.
install -Dpm 0644 %{SOURCE1} %{buildroot}/%{_mandir}/man1/proxy.1


%check
%ctest

%files
%license COPYING
%{_libdir}/*.so.*
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/%{version}
%dir %{_libdir}/%{name}/%{version}/modules

%files doc
%doc AUTHORS README

%files bin
%{_bindir}/proxy
%{_mandir}/man1/proxy.1*

%if %{without bootstrap}
%files -n python3-%{name}
%{python3_sitelib}/__pycache__/*
%{python3_sitelib}/%{name}.*

%files gnome
%{_libdir}/%{name}/%{version}/modules/config_gnome3.so
%{_libexecdir}/pxgsettings

%files networkmanager
%{_libdir}/%{name}/%{version}/modules/network_networkmanager.so

%files duktape
%{_libdir}/%{name}/%{version}/modules/pacrunner_duktape.so

%files pacrunner
%{_libdir}/%{name}/%{version}/modules/config_pacrunner.so
%endif

%files devel
%{_includedir}/proxy.h
%{_libdir}/*.so
%{_libdir}/pkgconfig/libproxy-1.0.pc
%{_datadir}/cmake/Modules/Findlibproxy.cmake


%changelog
* Sun Feb 12 2023 Funda Wang <fundawang@yeah.net> - 0.4.18-2
- Use duktape instead of webkitgtk as js engine

* Wed Sep 21 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 0.4.18-1
- update to 0.4.18

* Thu Apr 07 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 0.4.17-1
- Init from upstream version 0.4.17

